Vcmax, Jmax, Rd0
and G1. However, the model contains many other parameters, each with
their own default value. To override the default value, for example:
# Use Default values: Farquhar(PAR=1000, Tair=20, Ca=380,
VPD=1, Vcmax=100, Jmax=150, Rd0=1)
# Change the shape of the light response curve: Farquhar(PAR=1000, Tair=20,
Ca=380, VPD=1, Vcmax=100, Jmax=150, Rd0=1, THETA=0.8) Below is a list and
explanation of all the parameters and their default values.
# Respiration parameters Q10F = 0.67 # logarithm of the Q10
(Equation for respiration : # RESP = RD0 * EXP(Q10F * (TLEAF-RTEMP)/10) *
DAYRESP RTEMP = 25 # Reference temperature (T at which RD0 was measured)
DAYRESP = 1.0 # Respiration in the light as fraction of that in the dark.
TBELOW = -100.0 # No respiration occurs below this temperature (degC).
# Stomatal conductance parameters MODELGS = 4 # model : 4 = Medlyn et al.
2011; 6 = Tuzet et al. 2003. EMAXLEAF = 999 # Only used when considering
soil water stress and MODELGS is not 6. KTOT = 2 # Leaf-specific hydraulic
conductance (mmol m-2 s-1 MPa-1)
G0 = 0.03 # Stomatal leakiness (gs when photosynthesis is zero).
D0L = 5 # Parameter for the Leuning model (MODELGS=3) GAMMA = 0 # Gamma for
all Ball-Berry type models G1 = 7 # Parameter for all Ball-Berry type models
GK = 0.3 # Parameter for three-parameter Medlyn et al. 2011 model (MODELGS=5)
SF = 3.2 # Tuzet model parameters (MODELGS=6) PSIV = -1.9
# Light-response parameters of electron transport rate. THETA = 0.4 # Shape
parameter of the non-rectangular hyperbola. AJQ = 0.324 # Quantum yield of
electron transport. HMSHAPE = 0.999 # Shape of the hyperbolic minimum
function (no need to change)
# Temperature response parameters. # Parameters for Jmax. EAVJ = 37259 # Ha
in Medlyn et al. (2002) EDVJ = 200000 # Hd in Medlyn et al. (2002) DELSJ =
640.02 # DELTAS in Medlyn et al. (2002)
# Parameters for Vcmax. EAVC = 47590 # Ha in Medlyn et al. (2002) EDVC = 0.0
# Hd in Medlyn et al. (2002) DELSC = 0.0 # DELTAS in Medlyn et al. (2002)Farquhar(PAR, Tair, Ca, VPD, RH = 0, Patm = 101, SWP = 0, Vcmax, Jmax,
Rd0, G1, ...)lightresponse,setPhy# A ypphy object, using the coupled Farquhar model.
eucphy <- setPhy("Farquhar", leafpars=list(Vcmax=50, Jmax=100, G1=8, G0=0.01, Rd0=1))
# The 'print' method reminds you what it is:
eucphyRun the code above in your browser using DataLab