runYplant and YplantDay.QuasiMC is developed by Cieslak et al. (2008), which is part of the Virtual Laboratory plant modelling software created at the University of Calgary (http://www.algorithmicbotany.org).
Both files are placed in the directory (for windows, c:/QuasiMC),
which is created if it does not exist already.
This function can also be used to update an existing installation.
installQuasiMC()