Learn R Programming

YplantQMC (version 0.6-3)

leafdispersion: Leaf dispersion of 3D plants

Description

This function calculates the leaf dispersion for 3D plants, following Duursma et al. (2012). The method is based on the mean distance to k nearest neighbors in 3D. The function 'leafdispersion' computes this observed mean distance (Ok) for a plant (an object of class plant3d), as well as for a square box with randomly distributed leaves at the same leaf area density.

Usage

leafdispersion(plant, kneighbors = 5, nreplicate = 10, nleaves = NA,
  crownvol = NA)

Arguments

plant
An object of class 'plant3d'.
kneighbors
Number of neighbors to be used.
nreplicate
For the random distribution, the number of replicates to simulate.
crownvol,nleaves
Crown volume and number of leaves - optional. If not provided, they are calculated from the 'plant' object.

Value

  • A list with the following components: [object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]

References

Duursma, R.A., D.S. Falster, F. Valladares, F.J. Sterck, R.W. Pearcy, C.H. Lusk, K.M. Sendall, M. Nordenstahl, N.C. Houter, B.J. Atwell, N. Kelly, J.W.G. Kelly, M. Liberloo, D.T. Tissue, B.E. Medlyn and D.S. Ellsworth. 2012. Light interception efficiency explained by two simple variables: a test using a diversity of small- to medium-sized woody plants. New Phytologist. 193:397-408.

Examples

Run this code
# Leafdispersion for the Toona plant
leafdispersion(toona)

Run the code above in your browser using DataLab