leaffile.
readl(lfile = NA)leaffile. Currently, only a plot method
exists (see plot.leaffile).
Contrary to the original Yplant, readl is a bit picky with leaffiles:
there must be a point in the leaffile where X=0 (apart from the first and
last points), which is used to find the 'midrib', which in turn is used to
calculate leaf length.
plot.leaffile