Learn R Programming

YplantQMC (version 0.6-3)

readp: Reads the data from a .p file.

Description

Reads all data of the plant input file (.p) into a dataframe.

Usage

readp(pfile = NA)

Arguments

pfile
Name of the p file (a character string).

Value

  • Dataframe. The column names correspond to the labels in the .p file, but duplicates have a numeric subscript; [object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object] More detail on the leaf angles: [object Object],[object Object],[object Object]