Learn R Programming

YplantQMC (version 0.6-6)

turtle482: A turtle sky with 482 points

Description

A set of points that are uniformly distributed across the hemisphere, so that each point represents (approx.) the same solid angle. Used in the diffuse radiation calculations in YplantDay.

Arguments

Format

A data frame with 482 observations on the following 2 variables.
altitude
a numeric vector
azimuth
a numeric vector