Learn R Programming

YplantQMC (version 0.6-3)

ypreport: Make a PDF report of several YplantQMC objects

Description

Produce a report containing standard graphs and summaries of YplantQMC objects. See Details for usage. This function produces a number of standard plots and prints of five different YplantQMC objects. The plots cannot at the moment not be customized; please see below for the component functions that generate the plots (these usually have more options for customization). Or, modify the code of ypreport as you see fit. To create a report, simply use this command: ypreport(plant=myplant, met=asunnyday, phy=eucleaf, hemi=mycanopy, ypsim=eucsim1) Where myplant, asunnyday, eucleaf, mycanopy and eucsim1 are objects that you have already generated. The function is flexible : you can generate a report on a subset of the objects, for example only on the hemiphoto and the plant: ypreport(plant=myplant, hemi=spruceforest) You may want to check out the following functions, which are used in ypreport: [object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]

Usage

ypreport(plant = NULL, phy = NULL, met = NULL, hemi = NULL,
  ypsim = NULL, filename = NA)

Arguments

plant
An object of class 'plant3d', see constructplant
phy
An object of class 'ypphy', see setPhy
met
An object of class 'ypmet', see setMet
hemi
An object of class 'yphemi', see setHemi
ypsim
An object of class 'yplantsim', see YplantDay
filename
Optional, the name of the output file

Value

  • A PDF is generated in the current working directory.

See Also

plot.plant3d,viewplot,YplantDay