Learn R Programming

YplantQMC (version 0.6-3)

installQuasiMC: Download and install the QuasiMC executable

Description

Downloads the Windows/Mac executable necessary for running runYplant and YplantDay. QuasiMC is developed by Cieslak et al. (2008), which is part of the Virtual Laboratory plant modelling software created at the University of Calgary (http://www.algorithmicbotany.org). Both files are placed in the directory (for windows, c:/QuasiMC), which is created if it does not exist already. This function can also be used to update an existing installation.

Usage

installQuasiMC(proxy = FALSE)

Arguments

proxy
Use TRUE if connecting through a proxy. This invokes setInternet2

References

Cieslak, M., C. Lemieux, J. Hanan and P. Prusinkiewicz. 2008. Quasi-Monte Carlo simulation of the light environment of plants. Functional Plant Biology. 35:837-849. See also http://www.remkoduursma/yplantqmc