## Not run:
# # An ellipsoid shape crown, write a Q file to disk.
# # Specify approximate total leaf area.
# randomplant(radius=400, height=2000, shape="ELIP",
# leaflen=40, LA=1.5, writefile=TRUE)
#
# # Embed the function in a call to 'constructplant', giving a plant in the
# # YplantQMC format.
# # Because no leaf file is specified, it uses a built-in triangle-shaped leaf.
# coneplant <- constructplant(randomplant(radius=250, height=500, shape="CONE",
# leaflen=25, LA=1))
#
# ## End(Not run)
Run the code above in your browser using DataLab