Learn R Programming

YplantQMC (version 0.6-3)

readl: Read a Yplant leaf file

Description

Reads a Yplant leaf file (.l or .lf) into an object of class leaffile.

Usage

readl(lfile = NA)

Arguments

lfile
Name of the leaf file (character string).

Value

  • An object of class leaffile. Currently, only a plot method exists (see plot.leaffile).

Details

NOTE: if there are more than one leaf type type in the leaffile, it only reads the first one. At the moment, YplantQMC only uses one leaf file for all leaves in the canopy. Contrary to the original Yplant, readl is a bit picky with leaffiles: there must be a point in the leaffile where X=0 (apart from the first and last points), which is used to find the 'midrib', which in turn is used to calculate leaf length.

See Also

plot.leaffile