Learn R Programming

YplantQMC (version 0.6-3)

turtle482: A turtle sky with 482 points

Description

A set of points that are uniformly distributed across the hemisphere, so that each point represents (approx.) the same solid angle. Used in the diffuse radiation calculations in YplantDay.

Arguments